Struct ExtrasAddonInfo
pub struct ExtrasAddonInfo {
pub api_version: u32,
pub max_info_version: u32,
pub string_version: Option<&'static str>,
}Expand description
Information about the Unofficial Extras addon.
Fields
api_version: u32Version of the API.
Gets incremented whenever a function signature or behavior changes in a breaking way.
max_info_version: u32Highest known version of the ExtrasSubscriberInfo struct.
Also determines the size of the subscriber info buffer in the init call.
The buffer is only guaranteed to have enough space for known ExtrasSubscriberInfo versions.
string_version: Option<&'static str>String version of the Unofficial Extras addon.
Gets changed on every release.
Implementations
impl ExtrasAddonInfo
impl ExtrasAddonInfo
pub fn version(&self) -> ExtrasVersion
pub fn version(&self) -> ExtrasVersion
Returns the corresponding ExtrasVersion.